eprllib.Agents.Filters.DefaultFilter
====================================

.. automodule:: eprllib.Agents.Filters.DefaultFilter

   
   .. rubric:: Classes

   .. autosummary::
   
      DefaultFilter
   